/*
 * Copyright (C) 2019  Kevin Whitaker <eyecreate@eyecreate.org>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "bluetoothdevices.h"
#include <QBluetoothAddress>

BluetoothDevices::BluetoothDevices(QBluetoothDeviceInfo info)
{
    this->m_device = info;
    this->m_address = info.address().toString();
    this->m_name = info.name();
}

QBluetoothDeviceInfo BluetoothDevices::device() const
{
    return m_device;
}

void BluetoothDevices::setDevice(const QBluetoothDeviceInfo& device)
{
    if (m_device == device) {
        return;
    }

    m_device = device;
    emit deviceChanged(m_device);
}

QString BluetoothDevices::address() const
{
    return m_address;
}

void BluetoothDevices::setAddress(const QString& address)
{
    if (m_address == address) {
        return;
    }

    m_address = address;
    emit addressChanged(m_address);
}

QString BluetoothDevices::name() const
{
    return m_name;
}

void BluetoothDevices::setName(const QString& name)
{
    if (m_name == name) {
        return;
    }

    m_name = name;
    emit nameChanged(m_name);
}
