/*
 * Copyright (C) 2019  Kevin Whitaker <eyecreate@eyecreate.org>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef BLUETOOTHDEVICES_H
#define BLUETOOTHDEVICES_H

#include <QObject>
#include <QBluetoothDeviceInfo>

/**
 * Data class used to represent found MiFlora devices.
 */
class BluetoothDevices : public QObject
{
    Q_OBJECT
    Q_PROPERTY(QBluetoothDeviceInfo device READ device WRITE setDevice NOTIFY deviceChanged)
    Q_PROPERTY(QString address READ address WRITE setAddress NOTIFY addressChanged)
    Q_PROPERTY(QString name READ name WRITE setName NOTIFY nameChanged)

public:
    
    BluetoothDevices(QBluetoothDeviceInfo info);

    /**
     * @return the device
     */
    QBluetoothDeviceInfo device() const;

    /**
     * @return the address
     */
    QString address() const;

    /**
     * @return the name
     */
    QString name() const;

public Q_SLOTS:
    /**
     * Sets the device.
     *
     * @param device the new device
     */
    void setDevice(const QBluetoothDeviceInfo& device);

    /**
     * Sets the address.
     *
     * @param address the new address
     */
    void setAddress(const QString& address);

    /**
     * Sets the name.
     *
     * @param name the new name
     */
    void setName(const QString& name);

Q_SIGNALS:
    void deviceChanged(const QBluetoothDeviceInfo& device);

    void addressChanged(const QString& address);

    void nameChanged(const QString& name);

private:
    QBluetoothDeviceInfo m_device;
    QString m_address;
    QString m_name;
};

#endif // BLUETOOTHDEVICES_H
