/*
 * Copyright (C) 2019  Kevin Whitaker <eyecreate@eyecreate.org>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef FLORAHISTORY_H
#define FLORAHISTORY_H

#include <qabstractitemmodel.h>
#include <QDateTime>
#include <QList>

/**
 * Model class to hold history data from MiFlora device.
 */
class FloraHistory : public QAbstractTableModel
{
    Q_OBJECT

public:
    
    QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const override;

    int columnCount(const QModelIndex& parent) const override;

    int rowCount(const QModelIndex& parent) const override;
    
    void clear();
    
    void addData(QDateTime time, float temperature, quint32 brightness, quint8 moisture, quint16 conductivity);
    
private:
    struct flora_data {
        QDateTime time;
        float temperature;
        quint32 brightness;
        quint8 moisture;
        quint16 conductivity;
        
    };
    QList<flora_data> tableData;

};

#endif // FLORAHISTORY_H
